@@ -7,13 +7,13 @@ from traceback import format_stack
 
 from msgpack import ExtType
 
-from .buffer import Buffer
-from .common import (Remote, RemoteApi, RemoteMap, RemoteSequence,
-                     decode_if_bytes, walk)
-from .tabpage import Tabpage
-from .window import Window
-from ..compat import IS_PYTHON3
-from ..util import Version, format_exc_skip
+from pynvim.api.buffer import Buffer
+from pynvim.api.common import (NvimError, Remote, RemoteApi, RemoteMap, RemoteSequence,
+                               decode_if_bytes, walk)
+from pynvim.api.tabpage import Tabpage
+from pynvim.api.window import Window
+from pynvim.compat import IS_PYTHON3
+from pynvim.util import Version, format_exc_skip
 
 __all__ = ('Nvim')
 
@@ -76,8 +76,8 @@ class Nvim(object):
         queries Nvim metadata for type information and sets a SessionHook for
         creating specialized objects from Nvim remote handles.
         """
-        session.error_wrapper = lambda e: NvimError(e[1])
-        channel_id, metadata = session.request(b'vim_get_api_info')
+        session.error_wrapper = lambda e: NvimError(decode_if_bytes(e[1]))
+        channel_id, metadata = session.request(b'nvim_get_api_info')
 
         if IS_PYTHON3:
             # decode all metadata strings for python3
@@ -107,8 +107,8 @@ class Nvim(object):
         self.version = Version(**version)
         self.types = types
         self.api = RemoteApi(self, 'nvim_')
-        self.vars = RemoteMap(self, 'nvim_get_var', 'nvim_set_var')
-        self.vvars = RemoteMap(self, 'nvim_get_vvar', None)
+        self.vars = RemoteMap(self, 'nvim_get_var', 'nvim_set_var', 'nvim_del_var')
+        self.vvars = RemoteMap(self, 'nvim_get_vvar', None, None)
         self.options = RemoteMap(self, 'nvim_get_option', 'nvim_set_option')
         self.buffers = Buffers(self)
         self.windows = RemoteSequence(self, 'nvim_list_wins')
@@ -389,11 +389,17 @@ class Nvim(object):
                             from_part, do_lt, special)
 
     def out_write(self, msg, **kwargs):
-        """Print `msg` as a normal message."""
+        r"""Print `msg` as a normal message.
+
+        The message is buffered (won't display) until linefeed ("\n").
+        """
         return self.request('nvim_out_write', msg, **kwargs)
 
     def err_write(self, msg, **kwargs):
-        """Print `msg` as an error message."""
+        r"""Print `msg` as an error message.
+
+        The message is buffered (won't display) until linefeed ("\n").
+        """
         if self._thread_invalid():
             # special case: if a non-main thread writes to stderr
             # i.e. due to an uncaught exception, pass it through
@@ -414,7 +420,7 @@ class Nvim(object):
         """
         try:
             self.command(quit_command)
-        except IOError:
+        except OSError:
             # sending a quit command will raise an IOError because the
             # connection is closed before a response is received. Safe to
             # ignore it.
@@ -569,7 +575,3 @@ class LuaFuncs(object):
         pattern = "return {}(...)" if not async_ else "{}(...)"
         code = pattern.format(self.name)
         return self._nvim.exec_lua(code, *args, **kwargs)
-
-
-class NvimError(Exception):
-    pass
